==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name The name of the field.
 * @property type The data type of the field. Valid values: `Number`, `String`, `Boolean`.
 */
public data class IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs(
    public val name: Output<String>? = null,
    public val type: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.iot.inputs.IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs> {
    override fun toJava():
        com.pulumi.aws.iot.inputs.IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs =
        com.pulumi.aws.iot.inputs.IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs].
 */
@PulumiTagMarker
public class IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgsBuilder internal
constructor() {
    private var name: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The name of the field.
     */
    @JvmName("xiuxlifbpbcywoah")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The data type of the field. Valid values: `Number`, `String`, `Boolean`.
     */
    @JvmName("aijrvikrskajwakg")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The name of the field.
     */
    @JvmName("qwescycqexkqanki")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The data type of the field. Valid values: `Number`, `String`, `Boolean`.
     */
    @JvmName("gcfffjvmavpmcgap")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs =
        IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs(
            name = name,
            type = type,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name The name of the field.
 * @property type The data type of the field. Valid values: `Number`, `String`, `Boolean`.
 */
public data class IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs(
    public val name: Output<String>? = null,
    public val type: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.iot.inputs.IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs =
        com.pulumi.aws.iot.inputs.IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs].
 */
@PulumiTagMarker
public class IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The name of the field.
     */
    @JvmName("nlfagsjebdrrnkmr")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The data type of the field. Valid values: `Number`, `String`, `Boolean`.
     */
    @JvmName("mbctljsinlrnrnbh")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The name of the field.
     */
    @JvmName("tsjopkuevbbijfph")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The data type of the field. Valid values: `Number`, `String`, `Boolean`.
     */
    @JvmName("nofynpoqjrpmlvtn")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs =
        IndexingConfigurationThingGroupIndexingConfigurationManagedFieldArgs(
            name = name,
            type = type,
        )
}
